==> okteta-17.08.2.tar.xz: okteta-17.08.2/libs/kasten/gui/io/filesystem/modelencoderfilesystemexporterconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODELENCODERFILESYSTEMEXPORTERCONFIGEDITORFACTORY_H
#define MODELENCODERFILESYSTEMEXPORTERCONFIGEDITORFACTORY_H

// lib
#include <kasten/abstractmodelexporterconfigeditorfactory.h>


namespace Kasten
{

class AbstractModelStreamEncoderConfigEditorFactory;


class KASTENGUI_EXPORT ModelEncoderFileSystemExporterConfigEditorFactory : public AbstractModelExporterConfigEditorFactory
{
  public:
    explicit ModelEncoderFileSystemExporterConfigEditorFactory( AbstractModelStreamEncoderConfigEditorFactory* encoderConfigEditorFactory );
    virtual ~ModelEncoderFileSystemExporterConfigEditorFactory();

  public:
    virtual AbstractModelExporterConfigEditor* tryCreateConfigEditor( AbstractModelExporter* exporter ) const;

  protected:
    AbstractModelStreamEncoderConfigEditorFactory* mEncoderConfigEditorFactory;
};

}

#endif

==> okteta_17.12.3.orig.tar.xz: okteta-17.12.3/libs/kasten/gui/io/filesystem/modelencoderfilesystemexporterconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef MODELENCODERFILESYSTEMEXPORTERCONFIGEDITORFACTORY_H
#define MODELENCODERFILESYSTEMEXPORTERCONFIGEDITORFACTORY_H

// lib
#include <kasten/abstractmodelexporterconfigeditorfactory.h>


namespace Kasten
{

class AbstractModelStreamEncoderConfigEditorFactory;


class KASTENGUI_EXPORT ModelEncoderFileSystemExporterConfigEditorFactory : public AbstractModelExporterConfigEditorFactory
{
  public:
    explicit ModelEncoderFileSystemExporterConfigEditorFactory( AbstractModelStreamEncoderConfigEditorFactory* encoderConfigEditorFactory );
    ~ModelEncoderFileSystemExporterConfigEditorFactory() override;

  public:
    AbstractModelExporterConfigEditor* tryCreateConfigEditor( AbstractModelExporter* exporter ) const override;

  protected:
    AbstractModelStreamEncoderConfigEditorFactory* mEncoderConfigEditorFactory;
};

}

#endif
